import { __rest } from "tslib";
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from "@emotion/react";
import * as React from "react";
import { Text, LabelText } from "./Text";
import VisuallyHidden from "@reach/visually-hidden";
import PropTypes from "prop-types";
import { alpha } from "./Theme/colors";
import { useUid } from "./Hooks/use-uid";
import { useTheme } from "./Theme/Providers";
import { getHeight, focusShadow } from "./Button";
import { IconAlertCircle, IconChevronDown } from "./Icons";
import { safeBind } from "./Hooks/compose-bind";
import { useMedia } from "use-media";
import Switch from "react-switch";
//似乎<form action= omsubmit= /> 都不再需要使用了。
/*
自适应布局，容器父组件不应当设置width固定的px，否则内部组件元素{已经为屏幕宽度自适应适配的组件}都会被动拉伸宽度，失去了效果。
*/
const getInputSizes = (theme) => ({
    sm: css({
        fontSize: theme.fontSizes[0],
        padding: "0.25rem 0.5rem"
    }),
    md: css({
        fontSize: theme.fontSizes[1],
        padding: "0.5rem 0.75rem"
    }),
    lg: css({
        fontSize: theme.fontSizes[2],
        padding: "0.65rem 1rem"
    })
});
const InputGroupContext = React.createContext({
    uid: undefined,
    error: undefined
});
export const InputGroup = (_a) => {
    var { id, label, children, error, helpText, hideLabel, labelStyle, labelTextStyle } = _a, other = __rest(_a, ["id", "label", "children", "error", "helpText", "hideLabel", "labelStyle", "labelTextStyle"]);
    const uid = useUid(id);
    const theme = useTheme();
    const isDark = theme.colors.mode === "dark";
    const danger = isDark
        ? theme.colors.intent.danger.light
        : theme.colors.intent.danger.base;
    return (_jsxs("section", Object.assign({ className: "InputGroup", css: {
            marginTop: theme.spaces.md,
            "&.InputGroup:first-of-type": {
                marginTop: 0
            }
        } }, other, { children: [_jsx(Label, Object.assign({ hide: hideLabel, htmlFor: uid, css: labelStyle, textStyle: labelTextStyle }, { children: label }), void 0),
            _jsx(InputGroupContext.Provider, Object.assign({ value: {
                    uid,
                    error
                } }, { children: children }), void 0),
            error && typeof error === "string" ? (_jsxs("div", Object.assign({ className: "InputGroup__error", css: {
                    alignItems: "center",
                    marginTop: theme.spaces.sm,
                    display: "flex"
                } }, { children: [_jsx(IconAlertCircle, { size: "sm", color: danger }, void 0),
                    _jsx(Text, Object.assign({ css: {
                            display: "block",
                            marginLeft: theme.spaces.xs,
                            fontSize: theme.fontSizes[0],
                            color: danger
                        } }, { children: error }), void 0)] }), void 0)) : (error),
            helpText && (_jsx(Text, Object.assign({ className: "InputGroup__help", css: {
                    display: "block",
                    marginTop: theme.spaces.xs,
                    color: theme.colors.text.muted,
                    fontSize: theme.fontSizes[0]
                }, variant: "body" }, { children: helpText }), void 0))] }), void 0));
};
InputGroup.propTypes = {
    label: PropTypes.string.isRequired,
    hideLabel: PropTypes.bool,
    helpText: PropTypes.string,
    error: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
    id: PropTypes.string,
    children: PropTypes.node
};
function shadowBorder(color, opacity) {
    return `0 0 0 2px transparent inset, 0 0 0 1px ${alpha(color, opacity)} inset`;
}
function getBaseStyles(theme) {
    const dark = theme.colors.mode === "dark";
    const baseStyles = css({
        display: "block",
        width: "100%",
        lineHeight: theme.lineHeights.body,
        color: theme.colors.text.default,
        backgroundColor: "transparent",
        backgroundImage: "none",
        backgroundClip: "padding-box",
        WebkitFontSmoothing: "antialiased",
        WebkitTapHighlightColor: "transparent",
        WebkitAppearance: "none",
        boxSizing: "border-box",
        touchAction: "manipulation",
        fontFamily: theme.fonts.base,
        border: "none",
        boxShadow: dark
            ? shadowBorder(theme.colors.palette.gray.lightest, 0.14)
            : shadowBorder(theme.colors.palette.gray.dark, 0.2),
        borderRadius: theme.radii.sm,
        transition: "background 0.25s cubic-bezier(0.35,0,0.25,1), border-color 0.15s cubic-bezier(0.35,0,0.25,1), box-shadow 0.15s cubic-bezier(0.35,0,0.25,1)",
        "::placeholder": {
            color: alpha(theme.colors.text.default, 0.45)
        },
        ":focus": {
            boxShadow: dark
                ? focusShadow(alpha(theme.colors.palette.blue.light, 0.5), alpha(theme.colors.palette.gray.dark, 0.4), alpha(theme.colors.palette.gray.light, 0.2))
                : focusShadow(alpha(theme.colors.palette.blue.dark, 0.1), alpha(theme.colors.palette.gray.dark, 0.2), alpha(theme.colors.palette.gray.dark, 0.05)),
            outline: "none"
        },
        ":disabled": {
            opacity: dark ? 0.4 : 0.8,
            background: theme.colors.background.tint1,
            cursor: "not-allowed",
            boxShadow: dark
                ? shadowBorder(theme.colors.palette.gray.lightest, 0.15)
                : shadowBorder(theme.colors.palette.gray.dark, 0.12)
        },
        ":active": {
            background: theme.colors.background.tint1
        }
    });
    return baseStyles;
}
function useActiveStyle() {
    const [active, setActive] = React.useState(false);
    return {
        bind: {
            onTouchStart: () => setActive(true),
            onTouchEnd: () => setActive(false)
        },
        active
    };
}
function useSharedStyle() {
    const theme = useTheme();
    const errorStyles = {
        boxShadow: shadowBorder(theme.colors.intent.danger.base, 0.45)
    };
    const baseStyles = React.useMemo(() => getBaseStyles(theme), [theme]);
    const inputSizes = React.useMemo(() => getInputSizes(theme), [theme]);
    const activeBackground = css({ background: theme.colors.background.tint1 });
    return {
        baseStyles,
        inputSizes,
        activeBackground,
        errorStyles
    };
}
/**
 * Our basic Input element. Use this when building customized
 * forms. Otherwise, stick with InputGroup
 * 原先InputBase 改名成 InputRefBase; 比如ComboBox才会需要使用forwardRef形式的;
 */
export const InputRefBase = React.forwardRef((_a, ref) => {
    var { autoComplete, autoFocus, inputSize = "md", topDivStyle } = _a, other = __rest(_a, ["autoComplete", "autoFocus", "inputSize", "topDivStyle"]);
    const { uid, error } = React.useContext(InputGroupContext);
    const { bind, active } = useActiveStyle();
    const { baseStyles, inputSizes, activeBackground, errorStyles } = useSharedStyle();
    const height = getHeight(inputSize);
    return (_jsx("input", Object.assign({ id: uid, className: "Input", autoComplete: autoComplete, autoFocus: autoFocus }, bind, { css: [
            baseStyles,
            inputSizes[inputSize],
            active && activeBackground,
            error && errorStyles,
            { height }
        ] }, safeBind({ ref }, other)), void 0));
});
/**
 * 正常都不需要使用forwardRef形式的，可大大地加快速度。 InputRefBase是ref版本;
 * 性能优化，去掉了React.forwardRef 改成React.FunctionComponent
 * InputSimple普通FunctionComponent代替React.forwardRef(safeBind({ ref }就能从365ms变240ms啦。
 */
export const InputBase = (_a) => {
    var { autoComplete, autoFocus, inputSize = "md", topDivStyle } = _a, other = __rest(_a, ["autoComplete", "autoFocus", "inputSize", "topDivStyle"]);
    const { uid, error } = React.useContext(InputGroupContext);
    const { bind, active } = useActiveStyle();
    const { baseStyles, inputSizes, activeBackground, errorStyles } = useSharedStyle();
    const height = getHeight(inputSize);
    return (_jsx("input", Object.assign({ id: uid, className: "Input", autoComplete: autoComplete, autoFocus: autoFocus }, bind, { css: [
            baseStyles,
            inputSizes[inputSize],
            active && activeBackground,
            error && errorStyles,
            { height }
        ] }, other), void 0));
};
InputBase.propTypes = {
    inputSize: PropTypes.oneOf(["sm", "md", "lg"]),
    autoComplete: PropTypes.string,
    autoFocus: PropTypes.bool
};
/**
 * Input 比起InputBase，外面多包裹一个div以便于控制宽度和对齐。
 */
export const Input = (_a) => {
    var { autoComplete, autoFocus, inputSize = "md", fullWidth = true, topDivStyle } = _a, other = __rest(_a, ["autoComplete", "autoFocus", "inputSize", "fullWidth", "topDivStyle"]);
    const { uid, error } = React.useContext(InputGroupContext);
    const { bind, active } = useActiveStyle();
    const { baseStyles, inputSizes, activeBackground, errorStyles } = useSharedStyle();
    const height = getHeight(inputSize);
    return (_jsx("div", Object.assign({ css: [
            {
                textAlign: 'left',
                width: "100%"
            },
            topDivStyle
        ] }, { children: _jsx("input", Object.assign({ id: uid, className: "Input", autoComplete: autoComplete, autoFocus: autoFocus }, bind, { css: [
                baseStyles,
                inputSizes[inputSize],
                active && activeBackground,
                error && errorStyles,
                { height },
                !fullWidth && {
                    width: 'unset',
                }
            ] }, other), void 0) }), void 0));
};
/**
 * InputRefComp 是ref传递版本的Input,特别情况用
 * InputRefComp 比起 InputRefBase多个一层<div>可以注入控制样式,外面多包裹一个div以便于控制宽度和对齐。。
 */
export const InputRefComp = React.forwardRef((_a, ref) => {
    var { autoComplete, autoFocus, inputSize = "md", fullWidth = true, topDivStyle } = _a, other = __rest(_a, ["autoComplete", "autoFocus", "inputSize", "fullWidth", "topDivStyle"]);
    const { uid, error } = React.useContext(InputGroupContext);
    const { bind, active } = useActiveStyle();
    const { baseStyles, inputSizes, activeBackground, errorStyles } = useSharedStyle();
    const height = getHeight(inputSize);
    return (_jsx("div", Object.assign({ css: [
            {
                textAlign: 'left',
                width: "100%"
            },
            topDivStyle
        ] }, { children: _jsx("input", Object.assign({ id: uid, className: "Input", autoComplete: autoComplete, autoFocus: autoFocus }, bind, { css: [
                baseStyles,
                inputSizes[inputSize],
                active && activeBackground,
                error && errorStyles,
                { height },
                !fullWidth && {
                    width: 'unset',
                }
            ] }, safeBind({ ref }, other)), void 0) }), void 0));
});
/**
 * Textarea version of InputBase
 */
export const TextArea = (_a) => {
    var { inputSize = "md", topDivStyle } = _a, other = __rest(_a, ["inputSize", "topDivStyle"]);
    const { bind, active } = useActiveStyle();
    const { baseStyles, inputSizes, activeBackground, errorStyles } = useSharedStyle();
    const { uid, error } = React.useContext(InputGroupContext);
    return (_jsx("textarea", Object.assign({ className: "TextArea", id: uid }, bind, { css: [
            baseStyles,
            inputSizes[inputSize],
            {
                overflow: "auto",
                resize: "vertical",
            },
            active && activeBackground,
            error && errorStyles,
            topDivStyle
        ] }, other), void 0));
};
TextArea.propTypes = {
    inputSize: PropTypes.oneOf(["sm", "md", "lg"])
};
/**
 * A styled Label to go along with input elements
 */
export const Label = (_a) => {
    var { children, hide, textStyle } = _a, other = __rest(_a, ["children", "hide", "textStyle"]);
    const theme = useTheme();
    const child = (_jsx("label", Object.assign({ className: "Label", css: {
            display: "inline-block",
            marginBottom: hide ? 0 : theme.spaces.sm
        } }, other, { children: _jsx(Text, Object.assign({ className: "Label__text", variant: "subtitle", css: textStyle }, { children: children }), void 0) }), void 0));
    return hide ? _jsx(VisuallyHidden, { children: child }, void 0) : child;
};
Label.propTypes = {
    hide: PropTypes.bool,
    children: PropTypes.node
};
/**
 * multiple在手机上可以不展开列表了，但是选择2个以上在编辑框上面只能显示数目，不会显示选择那些必须点击进入才能看见。在电脑上面还是列表全部展开的形式。
 * 若multiple=true 导致直接拉开了，样式窗口高度都改变，失去UI一致性了『感觉不友好啊』。
 * 光光靠w3c标准也行不通, 难以通用，必须自己定制。
 * ComboBox不允许multiple；但是Select不允许自主添加新的列表项目，Select允许列表附加label描述文字代替value;
 * 若触摸屏 不能支持multiple形态的的Select，只能单选。?浏览器版本升级，但是还会有返回的数据【】集合机制问题,value=[values1,2]。
 * multiple 只是摊开选择列表，onChange  .target.value无法提供多选数组，必须额外维护可以多选的被选中状态和数据数组。
 *本来该用 children 的这个 <option></option> 也能够用...other直接复制<select 的底下标签去。
 */
export const Select = (_a) => {
    var { multiple, inputSize = "md", divStyle, topDivStyle } = _a, other = __rest(_a, ["multiple", "inputSize", "divStyle", "topDivStyle"]);
    const theme = useTheme();
    const inputSizes = getInputSizes(theme);
    const { uid, error } = React.useContext(InputGroupContext);
    const selectSize = {
        sm: inputSizes.sm,
        md: inputSizes.md,
        lg: inputSizes.lg
    };
    const dark = theme.colors.mode === "dark";
    const height = getHeight(inputSize);
    //因需要Select组件的max-width；导致Select若放InputGroupLine下在宽松模式一行内显示Label和Select的场景，在Select组件头层div设置宽度将会使得flex无法对齐两个项目；所以再套入一个div。
    return (_jsx("div", Object.assign({ css: [
            {
                textAlign: 'left'
            },
            topDivStyle
        ] }, { children: _jsxs("div", Object.assign({ className: "Select", css: [
                {
                    //这个position: "relative"因为其下级的position: "absolute"定位的小小图标所约束。所以只能relative或sticky其他position取值不行。
                    position: "relative",
                },
                divStyle,
            ] }, { children: [_jsx("select", Object.assign({ className: "Select__input", id: uid, css: [
                        selectSize[inputSize],
                        {
                            WebkitAppearance: "none",
                            display: "block",
                            width: "100%",
                            // lineHeight: theme.lineHeights.body,
                            height: multiple ? 'unset' : height,
                            color: theme.colors.text.default,
                            background: "transparent",
                            fontFamily: theme.fonts.base,
                            boxShadow: `0 0 0 2px transparent inset, 0 0 0 1px ${dark
                                ? alpha(theme.colors.palette.gray.lightest, 0.14)
                                : alpha(theme.colors.palette.gray.dark, 0.2)} inset`,
                            border: "none",
                            backgroundClip: "padding-box",
                            borderRadius: theme.radii.sm,
                            margin: 0,
                            ":disabled": {
                                ":disabled": {
                                    opacity: dark ? 0.4 : 0.8,
                                    background: theme.colors.background.tint1,
                                    cursor: "not-allowed",
                                    boxShadow: `0 0 0 2px transparent inset, 0 0 0 1px ${dark
                                        ? alpha(theme.colors.palette.gray.lightest, 0.15)
                                        : alpha(theme.colors.palette.gray.dark, 0.12)} inset`
                                }
                            },
                            ":focus": {
                                borderColor: theme.colors.palette.blue.base,
                                boxShadow: dark
                                    ? focusShadow(alpha(theme.colors.palette.blue.light, 0.5), alpha(theme.colors.palette.gray.dark, 0.4), alpha(theme.colors.palette.gray.light, 0.2))
                                    : focusShadow(alpha(theme.colors.palette.blue.dark, 0.1), alpha(theme.colors.palette.gray.dark, 0.2), alpha(theme.colors.palette.gray.dark, 0.05)),
                                outline: 0
                            }
                        },
                        error && {
                            boxShadow: shadowBorder(theme.colors.intent.danger.base, 0.45)
                        }
                    ], multiple: multiple }, other), void 0),
                !multiple && (_jsx(IconChevronDown, { className: "Select__icon", color: theme.colors.text.muted, css: {
                        position: "absolute",
                        top: "50%",
                        right: "0.75rem",
                        transform: "translateY(-50%)",
                        pointerEvents: "none"
                    } }, void 0))] }), void 0) }), void 0));
};
Select.propTypes = {
    inputSize: PropTypes.oneOf(["sm", "md", "lg"]),
    multiple: PropTypes.bool
};
export const Check = (_a) => {
    var { label, id, disabled, topDivStyle } = _a, other = __rest(_a, ["label", "id", "disabled", "topDivStyle"]);
    const uid = useUid(id);
    const theme = useTheme();
    return (_jsxs("div", Object.assign({ className: "Check", css: [
            {
                //  textAlign: 'left',
                display: "flex",
                alignItems: "center",
                //  width: "100%",
            },
            topDivStyle
        ] }, other, { children: [_jsx("input", Object.assign({ disabled: disabled, className: "Check__input", type: "checkbox", id: uid, css: [
                    {
                        height: '2rem',
                        width: '2rem',
                        display: 'inline-flex',
                        paddingLeft: '1rem',
                    },
                ] }, other), void 0),
            _jsx("label", Object.assign({ className: "Check__label", css: {
                    opacity: disabled ? 0.6 : undefined,
                    marginLeft: theme.spaces.xs
                }, htmlFor: uid }, { children: _jsx(Text, { children: label }, void 0) }), void 0)] }), void 0));
};
Check.propTypes = {
    label: PropTypes.string.isRequired,
    id: PropTypes.string,
    disabled: PropTypes.bool
};
/** SuffixInput 带单位标注的输入框
 * A styled Label to go along with input elements
 * 若children有，就是有附带单位后缀串的模式；
 * 带单位后缀的说明，70%给输入框，后面30%给叙述单位字串{空格也算}
 * 输入的 单位说明 字符串 放在 <Text className="Suffix__text"  >
 * 没有ref注入的版本；
 */
export const SuffixInput = (_a) => {
    var { children, textStyle, inputSize, topDivStyle } = _a, other = __rest(_a, ["children", "textStyle", "inputSize", "topDivStyle"]);
    //const theme = useTheme();
    //children可以是非字符串的, 按钮等。
    return (_jsxs("div", Object.assign({ css: [
            {
                textAlign: 'left'
                //display: "inline-block",
            },
            topDivStyle
        ] }, { children: [_jsx(InputBase, Object.assign({ inputSize: inputSize, css: {
                    display: "inline-block",
                    width: children ? "70%" : '100%',
                } }, other), void 0),
            typeof children === "string" ? (_jsx(Text, Object.assign({ className: "Suffix__text", variant: "subtitle", css: [
                    {
                        display: children ? "inline-flex" : 'none',
                        paddingLeft: '0.2rem'
                    },
                    textStyle
                ] }, { children: children }), void 0)) : (children)] }), void 0));
};
SuffixInput.propTypes = {
    children: PropTypes.node
};
/**
自适应屏幕flexBox布局：不要设置固定的width和min-width，可以设置max-width；根据屏幕宽策划1列2列还是更多列的并列，或是更高层次嵌套或隐藏或显示一小半边天区域。
不要对InputGroupLine的上一级div定义固定宽度，自适应和固定width: px只能二者选其一；宽度定了对小屏幕场景就有滚动条，而不是自适应缩小flexBox布局。
修改InputGroup排版模式; 并排模式，根据屏幕自适应。支持 2 个模式的布局安排结构。
 性能优化，旧版本InputGroupLine=680ms; 新的InputLine=600ms;
*/
export const InputLine = (_a) => {
    var { id, label, children, error, helpText, hideLabel, labelTextStyle, lineStyle, switchPx = 360 } = _a, other = __rest(_a, ["id", "label", "children", "error", "helpText", "hideLabel", "labelTextStyle", "lineStyle", "switchPx"]);
    const uid = useUid(id);
    const theme = useTheme();
    const isDark = theme.colors.mode === "dark";
    const danger = isDark
        ? theme.colors.intent.danger.light
        : theme.colors.intent.danger.base;
    //根据外部程序制定的px数，来决定用哪一个模式布局。紧凑的是2行显示；宽松的是并列在同一行。
    const fitable = useMedia({ minWidth: `${switchPx}px` });
    //InputGroupLine包裹的下层的顶级组件的样式修改：下层顶级元素的display: block还算兼容可用; 但width: 100%影响较大。
    const childNodeVar = (_jsx(InputGroupContext.Provider, Object.assign({ value: {
            uid,
            error
        } }, { children: React.cloneElement(children, {
            topDivStyle: { flex: '1 1 60%' },
            //style: { flex: '1 1 60%' },      左边的项目文字描述　40%　右边输入框(含单位字符)占用60%
        }) }), void 0));
    //这里htmlFor={uid}，标签label 和 input很可能分别属于不同div底下的。
    const titleVar = (_jsx(LabelText, Object.assign({ className: "Label__text", htmlFor: uid, css: [
            {
                //display: "inline-flex",
                textAlign: fitable ? "right" : "left",
                flex: '1 1 40%',
                paddingRight: '0.8rem',
                marginBottom: hideLabel ? 0 : theme.spaces.sm
            },
            labelTextStyle
        ] }, { children: label }), void 0));
    return (_jsxs("section", Object.assign({ className: "InputLine", css: {
            marginTop: theme.spaces.md,
            "&.InputLine:first-of-type": {
                marginTop: 0
            },
            textAlign: 'center'
        } }, other, { children: [_jsxs("div", Object.assign({ css: [
                    {
                        alignItems: "center",
                        justifyContent: "space-around",
                        display: "flex",
                        // flexWrap: 'wrap',
                        maxWidth: '950px',
                        margin: '0 auto',
                        paddingRight: fitable ? '0.5rem' : 'unset',
                    },
                    lineStyle
                ] }, { children: [hideLabel ? _jsx(VisuallyHidden, { children: titleVar }, void 0) : titleVar, fitable && childNodeVar] }), void 0), !fitable && childNodeVar, error && typeof error === "string" ? (_jsxs("div", Object.assign({ className: "InputGroup__error", css: {
                    alignItems: "center",
                    marginTop: theme.spaces.sm,
                    display: "flex",
                    justifyContent: 'center'
                } }, { children: [_jsx(IconAlertCircle, { size: "sm", color: danger }, void 0),
                    _jsx(Text, Object.assign({ css: {
                            display: "block",
                            marginLeft: theme.spaces.xs,
                            fontSize: theme.fontSizes[0],
                            color: danger
                        } }, { children: error }), void 0)] }), void 0)) : (error),
            helpText && (_jsx(Text, Object.assign({ className: "InputGroup__help", css: {
                    display: "inline-flex",
                    marginTop: theme.spaces.xs,
                    color: theme.colors.text.muted,
                    fontSize: theme.fontSizes[0]
                }, variant: "body" }, { children: helpText }), void 0))] }), void 0));
};
InputLine.propTypes = {
    label: PropTypes.string.isRequired,
    hideLabel: PropTypes.bool,
    helpText: PropTypes.string,
    error: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
    id: PropTypes.string,
    switchPx: PropTypes.number,
    children: PropTypes.node
};
/**底层浏览器已经做了现成的支持ComboBox，何必自己再搞那么麻烦呢。
 * 直接用W3C浏览器提供的<datalist标签？list做关联id,来做组合输入框，代替ComboBox组件
 *<datalist id=""> 实际上可以脱离<input 而存在的，比如作为全局的不改动的<datalist集合放在一起。 管理？分离掉了；
 * 还是自己包含<datalist维护好了。
 * InputDatalist对比ComboBox组件的弱点1非空编辑不能点击就显示所有列表2手机上列表展开位置与窗口大小太矮了3<option的label与value都显示出来感觉不好。
 * ，但比ComboBox有个有优势：1能够记住当前用户输入用过的以后再用。
 * 不过一般输入完成后再做点击修改的概率也不大，手机版本显示区域太小问题以后浏览器版本可能改进的。
 */
export const InputDatalist = (_a) => {
    var { autoComplete, autoFocus, inputSize = "md", fullWidth = true, datalist = [], topDivStyle, onListChange } = _a, other = __rest(_a, ["autoComplete", "autoFocus", "inputSize", "fullWidth", "datalist", "topDivStyle", "onListChange"]);
    const { uid, error } = React.useContext(InputGroupContext);
    const { bind, active } = useActiveStyle();
    const { baseStyles, inputSizes, activeBackground, errorStyles } = useSharedStyle();
    const height = getHeight(inputSize);
    //这个版本：不需要React.forwardRef(()=>{})的，注入ref性能损失， {...safeBind({ ref }, other)}
    return (_jsxs("div", Object.assign({ css: [
            {
                textAlign: 'left',
                width: "100%"
            },
            topDivStyle
        ] }, { children: [_jsx("datalist", Object.assign({ id: `list${uid}` }, { children: datalist.map((one, i) => {
                    return _jsx("option", { value: one }, i);
                }) }), void 0),
            _jsx("input", Object.assign({ id: uid, className: "Input", autoComplete: autoComplete, autoFocus: autoFocus }, bind, { css: [
                    baseStyles,
                    inputSizes[inputSize],
                    active && activeBackground,
                    error && errorStyles,
                    { height },
                    !fullWidth && {
                        width: 'unset',
                    }
                ] }, other, { list: `list${uid}`, onChange: e => onListChange(e.currentTarget.value || undefined) }), void 0)] }), void 0));
};
const getSwitchHeight = (size) => {
    if (size === "xs")
        return 16;
    else if (size === "sm")
        return 22;
    else if (size === "lg")
        return 36;
    else if (size === "xl")
        return 44;
    else
        return 28;
};
/**
 * 从‘react-switch’导入组件,做个可替代Check的更加美观的开关组件。
 * @param disabled
 * @param topDivStyle
 */
export const CheckSwitch = (_a) => {
    var { id, disabled, topDivStyle, checked, onChange, hsize = "md" } = _a, other = __rest(_a, ["id", "disabled", "topDivStyle", "checked", "onChange", "hsize"]);
    const { uid } = React.useContext(InputGroupContext);
    //不能用这个React.useCallback((checked,event,id) => {， 状态无法切换, 外面传递进来的onChange()还是旧的数据，无法更新成新数值。
    //onHandleChange用了 useCallback（,[]）: 就是捕获函数， onChange就无法变化了,所以被锁住更新。
    const onHandleChange = (checked) => {
        onChange(checked);
    };
    return (_jsx("div", Object.assign({ className: "Switch", css: [
            {
                display: "flex",
                alignItems: "center",
            },
            topDivStyle
        ] }, other, { children: _jsx(Switch, { id: uid, checked: checked, onChange: onHandleChange, disabled: disabled, height: getSwitchHeight(hsize), width: getSwitchHeight(hsize) * 2 }, void 0) }), void 0));
};
CheckSwitch.propTypes = {
    id: PropTypes.string,
    disabled: PropTypes.bool,
    hsize: PropTypes.oneOf(["xs", "sm", "md", "lg", "xl"])
};
//# sourceMappingURL=Form.js.map